
## Release Notes

<!-- **vx.x.x - xxdatexx** -->

**v0.1.7 - April 4, 2023**

- **FIXED** -- unit test fix

**v0.1.6 - April 4, 2023**

- **ENHANCEMENT** -- added localisation type to aitoff maps
- **FIXED** -- first time listen command no longer starteds from time zero but listens from first connection
- **FIXED** -- doc builds

**v0.1.5 - April 4, 2023**

- **FEATURE**: listen command added
- **FEATURE**: echo command added
- **FEATURE**: maps converted to ascii format
- **FEATURE**: maps rendered as aitoff plots
- **FEATURE**: meta.yaml file written with alert, FITS header and extra useful content

**v0.1.4 - March 16, 2023**

- fixing docsting test

